{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Mumble Quick Connect" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Mumble Quick Connect" %}
{% endblock header_nav_brand %}

{% block content %}
    <div class="aa-mumble-quick-connect">
        {% block aa_mumble_quick_connect_body %}
        {% endblock aa_mumble_quick_connect_body %}

        <div class="aa-mumble-quick-connect-footer mt-3 pt-3 border-top border-light">
            {% include "aa_mumble_quick_connect/partials/footer/app-translation-footer.html" %}
        </div>
    </div>
{% endblock %}
